declare namespace fengmang {
    interface IToggleMenu {
        /**
         * true代表显示菜单按钮，false代表隐藏菜单按钮
         * */
        isShow: boolean;
    }
    interface IToggleBackButton {
        /**
         * true代表显示菜单按钮，false代表隐藏菜单按钮
         * */
        isShow: boolean;
    }
    interface IOpenUI {
        /**
         * """login"":登录界面
         *  ""bindPhone"":绑定手机号
         * ""shareMenu"":分享菜单
         *""newsGraphic"":新闻图文详情
         *""newsVideo"":新闻视频详情
         * ""newsLink"":新闻外链详情
         * ""shortVideo"":短视频
         * ""subjectDetail"":专题详情
         * ""liveDetail"":直播详情
         * ""live"":直播
         * ""tv"":电视
         * ""web"":纯外链页面
         * ""showMenuItems"":显示底部菜单项"
         */
        type: 'login' | 'bindPhone' | 'shareMenu' | 'newsGraphic' | 'newsVideo' | 'newsLink' | 'shortVideo' | 'subjectDetail' | 'liveDetail' | 'live' | 'tv' | 'web' | 'showMenuItems';
        /**
         * type对应的传值
         *
         * 1、type 为 login、bindPhone、live、tv时 不传params
         * 2、type 为 newsGraphic、newsVideo、newsLink、shortVideo、subjectDetail、liveDetail
         *    {id:""}
         * 3、type 为 shortVideo
         *    {id:"",entrance:"", extendParams:{}}  // entrance：入口/来源  extendParams：扩展参数，值为dictionary类型
         * 4、 type 为 web
         *    {url:""}
         * 5、showMenuItems
         *    {firstItems:["qq","pyq"],secondItems:["like"]}
         *    该类型会弹出底部多功能弹窗，params参数和
         *    showMenuItems接口（编号10）返回值一致，点击item之后，同样调用
         *    clickMenuItem接口（编号11）
         */
        params: any;
    }
    interface IShowMenuItems {
        /**
         *暂时先定义如下类型，后续再扩展
          "copy": 复制链接
          "wechat": 分享至微信
          "pyq": 分享至朋友圈
          "qq": 分享至qq
          "like": 点赞
          "liked": 已点赞
          "collect": 收藏
          "collected": 已收藏
          "refresh"：刷新
         * */
        /**
         * 主items，底部弹窗的第一行
         *  */
        firstItems?: Array<string>;
        /**
         * 其他items，底部弹窗的第二行
         *  **/
        secondItems?: Array<string>;
    }
    interface ICopy {
        /**
         * 链接地址
         */
        url: string;
    }
    interface IShare {
        /**
         * 分享文本的标题
         */
        title: string;
        /**
         * 分享的描述文本
         */
        text: string;
        /**
         * 分享的链接地址
         */
        url: string;
        /**
         * 分享的图片地址
         */
        image: string;
        /**
         * "auto":自动适配类型，视传入的参数来决定（ios端才有该类型）
         *  "text":文本
         *  "image":图片
         *  "webPage":网页
         *  "app":应用
         * "audio":音频
         *  "video":视频
         *  "file":文件
         */
        type?: 'auto' | 'text' | 'image' | 'webPage' | 'app' | 'audio' | 'video' | 'file';
    }
    interface ILike {
        /**
         * 这里只有会两种值，要么"like",要么"liked"
         */
        type: 'like' | 'liked';
    }
    interface ICollect {
        /**
         * 这里只有会两种值，要么"collect",要么"collected"
         */
        type: 'collect' | 'collected';
    }
    interface IOpenURL {
        /**
         * 跳转链接，遵循scheme协议和http协议
         * 例如 taobao://item.taobao.com/item.htm?spm=a230r.1.14.8.6ca03c3491RTxQ&id=626185613595&ns=1&abbucket=20#detail
         */
        url: string;
    }
    interface IPopToUI {
        /**
         * "previous":上一个页面
         * "root": 根页面
         */
        type: 'previous' | 'root';
    }
    interface IPopGesture {
        /**
         * true代表启用侧滑手势，false代表禁用侧滑手势
         */
        enabled: boolean;
    }
    interface IAccountConflict {
        /**
         * 绑定是否成功
         */
        success: boolean;
        /**
         * 绑定成功之后的授权信息
         */
        params: {
            canComment: number;
            identity: number;
            isAuth: number;
            isLive: number;
            phone: string;
            token: string;
            uuid: string;
        };
    }
    interface ICancelAccount {
        /**
         * 注销是否成功
         */
        success: boolean;
    }
}
